@@ -7,6 +7,7 @@ features.
 """
 from .core import CoreMixin, FindDirection
 from .navigation import NavigationMixin
-from .registry import *
+from .registry import get_mixin, get_renderers, add_mixin, apply_to_node, add_mixin_to_document, \
+    add_mixins_to_document_node
 from .spatial import SpatialMixin, SpatialRender
 from .util import add_method_to_node
